handler

package
v0.0.0-...-ac64c08 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2024 License: GPL-3.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CompleteRole

type CompleteRole struct {
	Role      models.Role            `json:"role"`
	Passives  []models.PassiveDetail `json:"passives"`
	Abilities []models.AbilityDetail `json:"abilities"`
}

type Handler

type Handler struct {
	Db *pgxpool.Pool
}

func NewHandler

func NewHandler(db *pgxpool.Pool) *Handler

func (*Handler) CreatePlayerAbility

func (h *Handler) CreatePlayerAbility(c echo.Context) error

func (*Handler) DeleteGame

func (h *Handler) DeleteGame(c echo.Context) error

func (*Handler) DeletePlayer

func (h *Handler) DeletePlayer(c echo.Context) error

func (*Handler) GetAbilityByID

func (h *Handler) GetAbilityByID(c echo.Context) error

func (*Handler) GetAbilityByName

func (h *Handler) GetAbilityByName(c echo.Context) error

func (*Handler) GetAllAbilities

func (h *Handler) GetAllAbilities(c echo.Context) error

func (*Handler) GetAllAnyAbilities

func (h *Handler) GetAllAnyAbilities(c echo.Context) error

func (*Handler) GetAllCompleteRoles

func (h *Handler) GetAllCompleteRoles(c echo.Context) error

func (*Handler) GetAllGamePlayers

func (h *Handler) GetAllGamePlayers(c echo.Context) error

func (*Handler) GetAllGames

func (h *Handler) GetAllGames(c echo.Context) error

func (*Handler) GetAllRoles

func (h *Handler) GetAllRoles(c echo.Context) error

func (*Handler) GetAllRooms

func (h *Handler) GetAllRooms(c echo.Context) error

func (*Handler) GetAllStatuses

func (h *Handler) GetAllStatuses(c echo.Context) error

func (*Handler) GetCategoryByID

func (h *Handler) GetCategoryByID(c echo.Context) error

func (*Handler) GetCompleteRole

func (h *Handler) GetCompleteRole(c echo.Context) error

func (*Handler) GetGameByID

func (h *Handler) GetGameByID(c echo.Context) error

func (*Handler) GetPlayerAbilities

func (h *Handler) GetPlayerAbilities(c echo.Context) error

func (*Handler) GetPlayerAbility

func (h *Handler) GetPlayerAbility(c echo.Context) error

func (*Handler) GetPlayerByID

func (h *Handler) GetPlayerByID(c echo.Context) error

func (*Handler) GetPlayerNotes

func (h *Handler) GetPlayerNotes(c echo.Context) error

func (*Handler) GetRandomGame

func (h *Handler) GetRandomGame(c echo.Context) error

func (*Handler) GetRoleAbilities

func (h *Handler) GetRoleAbilities(c echo.Context) error

func (*Handler) GetRoleByID

func (h *Handler) GetRoleByID(c echo.Context) error

func (*Handler) GetRoleForAbility

func (h *Handler) GetRoleForAbility(c echo.Context) error

func (*Handler) GetRolePassives

func (h *Handler) GetRolePassives(c echo.Context) error

func (*Handler) GetRoomByID

func (h *Handler) GetRoomByID(c echo.Context) error

func (*Handler) GetRoomByName

func (h *Handler) GetRoomByName(c echo.Context) error

func (*Handler) InsertGame

func (h *Handler) InsertGame(c echo.Context) error

func (*Handler) InsertPlayer

func (h *Handler) InsertPlayer(c echo.Context) error

func (*Handler) SyncRolesCsv

func (h *Handler) SyncRolesCsv(c echo.Context) error

func (*Handler) SyncStatusDetailsCSV

func (h *Handler) SyncStatusDetailsCSV(c echo.Context) error

func (*Handler) UpdateGame

func (h *Handler) UpdateGame(c echo.Context) error

func (*Handler) UpdatePlayer

func (h *Handler) UpdatePlayer(c echo.Context) error

func (*Handler) UpdatePlayerAbility

func (h *Handler) UpdatePlayerAbility(c echo.Context) error

func (*Handler) UpdatePlayerNotes

func (h *Handler) UpdatePlayerNotes(c echo.Context) error

type TempCreateAbilityDetailParams

type TempCreateAbilityDetailParams struct {
	models.CreateAbilityDetailParams
	CategoryNames []string
}

FIXME: This is a temporary solution to not making abilities within its own function. Right now I dont have a db context here so I can't immediatly get the assocaited cateogries

Jump to